[Pcsclite-cvs-commit] r5176 - /trunk/Drivers/ccid/src/ccid.c

rousseau at users.alioth.debian.org rousseau at users.alioth.debian.org
Mon Aug 23 09:03:08 UTC 2010


Author: rousseau
Date: Mon Aug 23 09:03:02 2010
New Revision: 5176

URL: http://svn.debian.org/wsvn/pcsclite/?sc=1&rev=5176
Log:
ccid_open_hack_pre(): use InterruptRead() with a timeout of 100ms
instead of 10ms to give more time to the device to respond.

This allows the Gemalto SG CCID to always start correctly, not just once
in a while.

Modified:
    trunk/Drivers/ccid/src/ccid.c

Modified: trunk/Drivers/ccid/src/ccid.c
URL: http://svn.debian.org/wsvn/pcsclite/trunk/Drivers/ccid/src/ccid.c?rev=5176&op=diff
==============================================================================
--- trunk/Drivers/ccid/src/ccid.c (original)
+++ trunk/Drivers/ccid/src/ccid.c Mon Aug 23 09:03:02 2010
@@ -70,8 +70,8 @@
 	if (PROTOCOL_CCID == ccid_descriptor->bInterfaceProtocol)
 	{
 #ifndef TWIN_SERIAL
-		/* just wait for 10ms in case a notification is in the pipe */
-		(void)InterruptRead(reader_index, 10);
+		/* just wait for 100ms in case a notification is in the pipe */
+		(void)InterruptRead(reader_index, 100);
 #endif
 	}
 




More information about the Pcsclite-cvs-commit mailing list